function names = get_inst_names(inums)
% function names = get_inst_names(inums)  
%
% This function will return a cell arrray of strings, each of which contains 
% the instrument name/description for the corresponding patch in bank 0 of 
% the GM sample set. 
%
% Input:
%   inums [num]  - The instrument numbers whose names we are interested in.  
%                  NOTE: these are GM numbers and so are 0-indexed.  If
%                  empty, get all names [[]]
%
% Output:
%   names [cell] - Cell array of instrument names
%

% Copyright (C) 2010-2030 Graham Grindlay (grindlay@ee.columbia.edu)
%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

if nargin < 1
    inums = [];
end

all_names = {'Acoustic Grand Piano', 'Bright Acoustic Piano', ...
             'Electric Grand Piano', 'Honky-tonk Piano', ...
             'Electric Piano 1', 'Electric Piano 2', ...
             'Harpsichord', 'Clavinet', ...
             'Celesta', 'Glockenspiel', ...
             'Music Box', 'Vibraphone', ...
             'Marimba', 'Xylophone', ...
             'Tubular Bells', 'Dulcimer', ...
             'Drawbar Organ', 'Percussive Organ', ...
             'Rock Organ', 'Church Organ', ...
             'Reed Organ', 'Accordion', ...
             'Harmonica', 'Tango Accordion', ...
             'Acoustic Guitar (nylon)', 'Acoustic Guitar (steel)', ...
             'Electric Guitar (jazz)', 'Electric Guitar (clean)', ...
             'Electric Guitar (muted)', 'Overdriven Guitar', ...
             'Distortion Guitar', 'Guitar harmonics', ...
             'Acoustic Bass', 'Electric Bass (finger)', ...
             'Electric Bass (pick)', 'Fretless Bass', ...
             'Slap Bass 1', 'Slap Bass 2', ...
             'Synth Bass 1', 'Synth Bass 2', ...
             'Violin', 'Viola', ...
             'Cello', 'Contrabass', ...
             'Tremolo Strings', 'Pizzicato Strings', ...
             'Orchestral Harp',  'Timpani', ...
             'String Ensemble 1', 'String Ensemble 2', ...
             'Synth Strings 1', 'Synth Strings 2', ...
             'Choir Aahs', 'Voice Oohs', ...
             'Synth Choir', 'Orchestra Hit', ...
             'Trumpet', 'Trombone', ...
             'Tuba', 'Muted Trumpet', ...
             'French Horn', 'Brass Section', ...
             'Synth Brass 1', 'Synth Brass 2', ...
             'Soprano Sax', 'Alto Sax', ...
             'Tenor Sax', 'Baritone Sax', ...
             'Oboe', 'English Horn', ...
             'Bassoon', 'Clarinet', ...
             'Piccolo', 'Flute', ...
             'Recorder', 'Pan Flute', ...
             'Blown Bottle', 'Shakuhachi', ...
             'Whistle', 'Ocarina', ...
             'Lead 1 (square)', 'Lead 2 (sawtooth)', ...
             'Lead 3 (calliope)', 'Lead 4 (chiff)', ...
             'Lead 5 (charang)', 'Lead 6 (voice)', ...
             'Lead 7 (fifths)', 'Lead 8 (bass + lead)', ...
             'Pad 1 (new age)', 'Pad 2 (warm)', ...
             'Pad 3 (polysynth)', 'Pad 4 (choir)', ...
             'Pad 5 (bowed)', 'Pad 6 (metallic)', ...
             'Pad 7 (halo)', 'Pad 8 (sweep)', ...
             'FX 1 (rain)', 'FX 2 (soundtrack)', ...
             'FX 3 (crystal)', 'FX 4 (atmosphere)', ...
             'FX 5 (brightness)',  'FX 6 (goblins)', ...
             'FX 7 (echoes)',  'FX 8 (sci-fi)', ...
             'Sitar', 'Banjo', ...
             'Shamisen', 'Koto', ...
             'Kalimba', 'Bag pipe', ...
             'Fiddle', 'Shanai', ...
             'Tinkle Bell', 'Agogo', ...
             'Steel Drums',  'Woodblock', ...
             'Taiko Drum',  'Melodic Tom', ...
             'Synth Drum', 'Reverse Cymbal', ...
             'Guitar Fret Noise',  'Breath Noise', ...
             'Seashore', 'Bird Tweet', ...
             'Telephone Ring', 'Helicopter', ...
             'Applause', 'Gunshot', ...
             };

if isempty(inums)
    names = all_names;
else
    names = all_names(inums+1);
end
